@@ -38,7 +38,7 @@ RichText.__html__ = with_heading_ids
 
 
 class TextBlock(blocks.StructBlock):
-    value = blocks.RichTextBlock(required=False, features=settings.RICH_TEXT_FEATURES)
+    value = blocks.RichTextBlock(label="Text", required=False, features=settings.RICH_TEXT_FEATURES)
 
     class Meta:
         template = '%s/common/text.html' % constants.BLOCK_TEMPLATES_PATH
@@ -86,12 +86,19 @@ class BackgroundBlock(blocks.StructBlock):
     mobile = SvgBlock()
 
 
-class ButtonBlock(blocks.StructBlock):
+class LinkBlock(blocks.StructBlock):
     text = blocks.CharBlock(required=False)
-    link = blocks.URLBlock(required=False)
-    page = blocks.PageChooserBlock(required=False)
-    open_new_tab = blocks.BooleanBlock(default=False, required=False)
-    type = ButtonChoiceBlock()
+    link = blocks.URLBlock(required=False, label="Button link")
+    page = blocks.PageChooserBlock(required=False, label="Button Page")
+    open_new_tab = blocks.BooleanBlock(default=False, required=False, label="Button nouvel onglet")
+
+    class Meta:
+        template = '%s/common/link.html' % constants.BLOCK_TEMPLATES_PATH
+        label = "Link"
+
+
+class ButtonBlock(LinkBlock):
+    type = ButtonChoiceBlock(required=False, label="Button type")
 
     class Meta:
         template = '%s/common/button.html' % constants.BLOCK_TEMPLATES_PATH
