@@ -12,7 +12,7 @@ from webspace.cms.blocks.common import \
 class CustomCard(blocks.StructBlock):
     text = TextBlock()
     button = ButtonBlock()
-    icon = SvgWithSizeBlock()
+    icon = SvgWithSizeBlock(label="Icon")
     media = blocks.StreamBlock(
         [
             ('svg', SvgWithSizeBlock()),
@@ -30,7 +30,6 @@ class CustomCard(blocks.StructBlock):
 class CardsEntry(EntryBlock):
     amp_scripts = ['carousel']
     carousel = blocks.BooleanBlock(required=False)
-    carousel_cta = blocks.BooleanBlock(required=False, default=True)
     cards = blocks.StreamBlock(
         [
             ('custom', CustomCard()),
