@@ -14,8 +14,8 @@ from webspace.cms.blocks.common import \
 
 class ComponentTextEntry(EntryBlock):
     amp_scripts = ['iframe', 'form']
-    titles = TextBlock()
-    text = TextBlock()
+    titles = TextBlock(label="Titres")
+    text = TextBlock(label="Description")
     reverse = blocks.BooleanBlock(required=False, help_text="Permet de d'intervertir le component et la zone de texte")
     section = blocks.BooleanBlock(required=False, help_text="Permet de sectionner la zone de texte")
     align = AlignTextChoiceBlock(required=False)
@@ -26,7 +26,8 @@ class ComponentTextEntry(EntryBlock):
             ('embed', EmbedWithSizeBlock()),
             ('form', FormBlock()),
         ],
-        max_num=1
+        max_num=1,
+        required=False
     )
     buttons = blocks.StreamBlock(
         [
