@@ -575,6 +575,19 @@ class Command(BaseCommand):
         <p>Chaque semaine dans votre boite mail, un condensé de conseils et de nouvelles entreprises qui
             recrutent.</p>
         """
+        ws_settings.summary_text = """
+        <h2>Sommaire</h2>
+        <hr>
+        """
+        ws_settings.search_text = """
+        <h2>Recherche</h2>
+        <hr>
+        """
+        ws_settings.related_articles_text = """
+        <h2>Articles related</h2>
+        <hr>
+        """
+
         ws_settings.newsletter = Mocker.get_form('newsletter', nb_fields=1, head_text=False)
 
         ws_settings.facebook = mocker.URL_TEST
