@@ -121,15 +121,37 @@ class AWebspaceSettings(BaseSetting, ClusterableModel):
     location_address_country = models.CharField(default='', blank=True, max_length=100)
     founding_location = models.CharField(default='', blank=True, max_length=100)
 
+    summary_text = RichTextField(
+        blank=True,
+        default='',
+        help_text="Text qui apparait en haut du sommaire"
+    )
+    search_text = RichTextField(
+        blank=True,
+        default='',
+        help_text="Text qui apparait en haut de la recherche par tag"
+    )
+    related_articles_text = RichTextField(
+        blank=True,
+        default='',
+        help_text="Text qui apparait en haut des articles en lien"
+    )
+
     general_panels = [
         FieldPanel('language'),
         FieldPanel('ga_code'),
         FieldPanel('collect_text'),
-        FieldPanel('social_share_text'),
         SnippetChooserPanel('newsletter')
     ]
 
+    blog_panels = [
+        FieldPanel('summary_text'),
+        FieldPanel('search_text'),
+        FieldPanel('related_articles_text'),
+    ]
+
     socials_panels = [
+        FieldPanel('social_share_text'),
         FieldPanel('facebook'),
         FieldPanel('instagram'),
         FieldPanel('linkedin'),
@@ -166,6 +188,7 @@ class AWebspaceSettings(BaseSetting, ClusterableModel):
         ObjectList(brand_tab_panels, heading='Brand'),
         ObjectList(organization_panels, heading='Organization'),
         ObjectList(socials_panels, heading='Socials'),
+        ObjectList(blog_panels, heading='Articles'),
     ])
 
     class Meta:
